==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/text/l10n/ko.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "파일을 업로드함",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "업로드한 파일의 크기가 php.ini의 upload_max_filesize를 초과함",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "업로드한 파일의 크기가 HTML 폼에 지정한 MAX_FILE_SIZE를 초과함",
    "The file was only partially uploaded" : "파일이 일부분만 업로드됨",
    "No file was uploaded" : "업로드한 파일 없음",
    "Missing a temporary folder" : "임시 폴더 없음",
    "Could not write file to disk" : "디스크에 파일을 쓸 수 없음",
    "A PHP extension stopped the file upload" : "PHP 확장 기능에서 파일 업로드를 차단함",
    "No file uploaded or file size exceeds maximum of %s" : "파일이 업로드 되지 않았거나, 크기가 %s를 초과함",
    "Nextcloud Text" : "Nextcloud 텍스트",
    "text document" : "텍스트 문서",
    "New text file" : "새 텍스트 파일",
    "Create new text file" : "새 텍스트 파일 만들기",
    "Editing session has expired. Please reload the page." : "편집 세션이 만료되었습니다. 페이지를 새로고침 해주세요.",
    "{user} has mentioned you in the text document {node}" : "{user}님이 {node} 텍스트 문서에서 당신을 언급했습니다.",
    "This file cannot be displayed as download is disabled by the share" : "공유에서 다운로드가 비활성화 되었으므로 이 파일을 볼 수 없습니다.",
    "File not found" : "파일을 찾을 수 없음",
    "Readme" : "Readme",
    "Text" : "텍스트",
    "📝 Collaborative document editing" : "📝 협업 문서 편집",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "** 📝 협업 문서 편집!**\n\n- **📝 글쓰기에 집중:** 방해는 없이, 필요한 서식만 적용.\n- **🙋 함께 작업하기:** 친구 및 동료와 공유하고 협업하세요, Nextcloud를 사용하는지는 상관 없습니다!\n- **💾 공개된 형식:** 파일이 [Markdown](https://en.wikipedia.org/wiki/Markdown)으로 저장되어, 다른 텍스트 앱에서도 편집할 수 있습니다.\n- **✊ 강력한 기반:** 저희는 [🐈 tiptap](https://tiptap.scrumpy.io)을 사용하며 [🦉 ProseMirror](https://prosemirror.net)에 기반합니다. – 많은 감사 드립니다!",
    "Insert result" : "결과 삽입",
    "Nextcloud Assistant result copied" : "Nextcloud 어시스턴트 결과 복사됨",
    "Could not copy result to clipboard" : "클립보드에 결과를 복사할 수 없음",
    "Nextcloud Assistant" : "Nextcloud 어시스턴트",
    "Translate" : "번역:",
    "Show assistant results" : "어시스턴트 결과 표시",
    "Assistant results" : "어시스턴트 결과",
    "Show result" : "결과 표시",
    "Delete task" : "결과 삭제",
    "Reload" : "새로 고침",
    "Reconnect" : "재연결",
    "This file is opened read-only as it is currently locked by {user}." : "이 파일은 {user}에 의해 잠겨 있으므로 읽기 전용으로 열립니다.",
    "Close outline view" : "개요 닫기",
    "Outline" : "개요",
    "Enter your name so other people can see who is editing" : "누가 수정하고 있는 지 다른 사람들이 알 수 있도록 이름을 입력하세요.",
    "Edit guest name" : "손님 이름 편집하기",
    "Guest" : "손님",
    "Save guest name" : "손님 이름 저장하기",
    "Uploading multiple attachments failed." : "여러 첨부 파일을 업로드에 실패했습니다.",
    "Uploading attachment failed: {error}" : "첨부 파일 업로드 실패: {error}",
    "Uploading attachment failed." : "첨부 파일 업로드에 실패했습니다.",
    "Insert an attachment" : "첨부 파일 삽입",
    "Failed to insert from Files" : "파일로부터 삽입 실패",
    "Preview options" : "미리 보기 옵션",
    "Text only" : "텍스트만",
    "Show link preview" : "링크 미리 보기 표시",
    "Open in new tab" : "새 탭으로 열기",
    "Remove link" : "링크 제거",
    "Active people" : "활동 중인 사용자",
    "guest" : "손님",
    "Full width editor" : "전체 너비 편집기",
    "Open the Smart Picker" : "스마트 피커 열기",
    "Offline" : "오프라인",
    "Offline, changes will be saved when online" : "오프라인입니다. 변경 사항은 온라인이 되었을 때 저장됩니다.",
    "Saving …" : "저장중 …",
    "Saved" : "저장됨",
    "Last saved {lastSave}" : "마지막 저장 {lastSave}",
    "The document has been changed outside of the editor. The changes cannot be applied." : "문서가 에디터 밖에서 변경되었습니다. 변경사항이 적용되지 않습니다.",
    "Unsaved changes" : "저장하지 않은 변경 사항",
    "Save document" : "문서 저장",
    "Last saved" : "마지막 저장",
    "Formatting and shortcuts" : "서식 및 단축키",
    "Speed up your writing with simple shortcuts." : "간단한 단축키들로 글쓰기 속도를 높이세요.",
    "Just type the Markdown syntax or use keyboard shortcuts from below." : "마크다운 구문을 입력하거나 아래의 키보드 단축키를 사용하세요.",
    "Just type the Markdown syntax from below." : "아래의 마크다운 구문을 입력하세요.",
    "Style" : "스타일",
    "Syntax" : "구문",
    "Keyboard shortcuts" : "키보드 단축키",
    "New paragraph" : "새 문단",
    "Enter" : "Enter",
    "Hard line break" : "강제 줄 바꿈",
    "followed by" : "followed by",
    "Backspace" : "백스페이스",
    "Shift" : "쉬프트",
    "Bold" : "굵게",
    "Bold text" : "굵은 텍스트",
    "Italic" : "Italic체",
    "Italicized text" : "기울임꼴 텍스트",
    "Strikethrough" : "취소선",
    "Mistaken text" : "잘못된 텍스트",
    "Underline" : "밑줄",
    "Underlined text" : "밑줄 쳐진 텍스트",
    "Heading 1" : "제목 1",
    "Heading level 1" : "제목 단계 1",
    "Heading 6" : "제목 6",
    "Heading level 6" : "제목 단계 6",
    "Unordered list" : "순서 없는 목록",
    "An item" : "하나의 항목",
    "Ordered list" : "순서 있는 목록",
    "First item" : "첫 항목",
    "Checklist" : "체크리스트",
    "To-Do item" : "해야 할 일",
    "Blockquote" : "블록 인용",
    "Quoted text" : "인용문",
    "Code block" : "코드 블록",
    "Some code" : "코드",
    "Link" : "링크",
    "Insert emoji" : "이모지 삽입",
    "emoji" : "이모지",
    "Mention someone" : "누군가를 언급",
    "name" : "이름",
    "Smart picker" : "스마트 피커",
    "something" : "무언가",
    "Action" : "동작",
    "Undo" : "실행 취소",
    "Redo" : "다시 실행",
    "Toggle outline" : "외곽선 켜고 끄기",
    "Alt" : "Alt",
    "Cannot copy, please copy the link manually" : "복사할 수 없습니다, 링크를 수동으로 복사하세요.",
    "Copy link to clipboard" : "링크를 클립보드에 복사",
    "Edit link" : "링크 수정",
    "Save changes" : "설정 저장",
    "Cancel" : "취소",
    "URL" : "URL",
    "Upload from computer" : "컴퓨터에서 업로드",
    "Insert from Files" : "파일로부터 삽입",
    "Formatting help" : "서식 도움말",
    "Link to file or folder" : "파일이나 폴더로 링크",
    "Link to website" : "웹사이트로 링크",
    "Update link" : "링크 갱신",
    "_%n word_::_%n words_" : ["%n개 단어"],
    "_%n char_::_%n chars_" : ["%n개 글자"],
    "Remaining actions" : "남은 동작",
    "Editor actions" : "편집기 동작",
    "Formatting menu bar" : "서식 메뉴 바",
    "Translate from {language}" : "{language}에서 번역",
    "Translate to {language}" : "{language}(으)로 번역",
    "Translation failed" : "번역 실패",
    "To translate individual parts of the text, select it before using the translate function." : "텍스트의 부분들을 각각 번역하려면, 번역 기능을 사용하기 전 먼저 선택을 하세요.",
    "Translate from" : "다음을 번역",
    "Select language" : "언어 선택",
    "Text to translate from" : "번역할 텍스트",
    "to" : "에서",
    "Translate to" : "다음으로 번역",
    "Translated text result" : "번역된 텍스트 결과",
    "Replace" : "바꾸기",
    "Insert" : "삽입",
    "No emoji found" : "이모지 없음",
    "No command found" : "명령 없음",
    "No user found" : "사용자 없음",
    "No suggestion found" : "제안 없음",
    "Upload" : "업로드",
    "Edit" : "편집",
    "Copy code block" : "코드 블록 복사",
    "Copy code" : "코드 복사",
    "Code block options" : "코드 블록 옵션",
    "Code block language" : "코드 블록 언어",
    "e.g. php, javascript, json…" : "예: php, 자바스크립트, json",
    "Source code" : "소스 코드",
    "Diagram" : "다이어그램",
    "Both" : "둘 다",
    "Mermaid documentation" : "Mermaid 문서",
    "Failed to load" : "불러오기 실패",
    "Could not find image in attachments list." : "첨부 파일 목록에서 이미지를 찾지 못했습니다.",
    "Delete this attachment" : "이 첨부 파일 삭제",
    "Delete this image" : "이 이미지 삭제",
    "Add row before" : "앞에 행 추가",
    "Add row after" : "뒤에 행 추가",
    "Delete this row" : "이 행 삭제",
    "Left align column" : "열 왼쪽 정렬",
    "Center align column" : "열 중앙 정렬",
    "Right align column" : "열 오른쪽 정렬",
    "Add column before" : "앞에 열 추가",
    "Add column after" : "뒤에 열 추가",
    "Delete this column" : "이 열 삭제",
    "Delete this table" : "이 표 삭제",
    "Add row below" : "아래에 행 추가",
    "Show folder description" : "폴더 설명 보이기",
    "Hide outline" : "개요 숨기기",
    "Show outline" : "개요 보이기",
    "Done" : "완료",
    "Headings" : "제목",
    "Heading 2" : "제목 2",
    "Heading 3" : "제목 3",
    "Heading 4" : "제목 4",
    "Heading 5" : "제목 5",
    "Lists" : "목록",
    "To-Do list" : "해야 할 일 목록",
    "Increase indentation" : "들여쓰기 증가",
    "Decrease indentation" : "들여쓰기 감소",
    "Blocks" : "블록",
    "Info callout" : "정보 설명선",
    "Success callout" : "성공 설명선",
    "Warning callout" : "경고 설명선",
    "Danger callout" : "위험 설명선",
    "Table" : "표",
    "Details" : "세부사항",
    "Insert link" : "링크 삽입",
    "Insert attachment" : "첨부 파일 삽입",
    "Command" : "명령",
    "Ctrl" : "Ctrl",
    "Option" : "옵션",
    "Formatting" : "서식",
    "Select file or folder to link to" : "링크할 파일이나 폴더 선택",
    "Add folder description" : "폴더 설명 추가",
    "\"{name}\" already exist!" : "\"{name}\" (이)가 이미 존재합니다!",
    "Created \"{name}\"" : "\"{name}\" 생성함",
    "Copied to the clipboard" : "클립보드에 복사됨",
    "Could not copy to the clipboard" : "클립보드에 복사할 수 없음",
    "Front matter" : "머리말",
    "Link to this section" : "이 부분으로 링크",
    "Use current version" : "최근 버젼을 사용하십시오.",
    "Use the saved version" : "이전 버전 사용하기",
    "Document has been changed outside of the editor. The changes cannot be applied" : "문서가 에디터 밖에서 변경되었습니다. 변경사항이 적용되지 않습니다.",
    "Document could not be loaded. Please check your internet connection." : "문서를 가져올 수 없습니다. 인터넷 연결을 확인해주십시오.",
    "Document idle for {timeout} minutes, click to continue editing" : "문서가 {timeout}분동안 유휴 상태입니다. 클릭하여 편집을 계속하세요.",
    "Show author colors" : "작성자 색상 표시",
    "Author colors are only shown until everyone has closed the document." : "작성자 색상은 모두가 문서를 닫았을 때까지만 표시됩니다.",
    "Connection failed." : "연결에 실패했습니다.",
    "Detect language" : "언어 감지",
    "Callouts" : "설명선",
    "Info" : "정보",
    "Success" : "성공",
    "Warning" : "경고",
    "Danger" : "위험",
    "Control" : "제어:",
    "Add notes, lists or links …" : "메모나 목록, 링크를 추가하세요...",
    "Start writing, or try '/' to add, '@' to mention…" : "글쓰기를 시작하거나, '/' 로 추가하고 '@'로 언급하세요..."
},
"nplurals=1; plural=0;");

==> nextcloud-33.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/text/l10n/ko.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "파일을 업로드함",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "업로드한 파일의 크기가 php.ini의 upload_max_filesize를 초과함",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "업로드한 파일의 크기가 HTML 폼에 지정한 MAX_FILE_SIZE를 초과함",
    "The file was only partially uploaded" : "파일이 일부분만 업로드됨",
    "No file was uploaded" : "업로드한 파일 없음",
    "Missing a temporary folder" : "임시 폴더 없음",
    "Could not write file to disk" : "디스크에 파일을 쓸 수 없음",
    "A PHP extension stopped the file upload" : "PHP 확장 기능에서 파일 업로드를 차단함",
    "No file uploaded or file size exceeds maximum of %s" : "파일이 업로드 되지 않았거나, 크기가 %s를 초과함",
    "Nextcloud Text" : "Nextcloud 텍스트",
    "text document" : "텍스트 문서",
    "New text file" : "새 텍스트 파일",
    "Create new text file" : "새 텍스트 파일 만들기",
    "Editing session has expired. Please reload the page." : "편집 세션이 만료되었습니다. 페이지를 새로고침 해주세요.",
    "{user} has mentioned you in the text document {node}" : "{user}님이 {node} 텍스트 문서에서 당신을 언급했습니다.",
    "This file cannot be displayed as download is disabled by the share" : "공유에서 다운로드가 비활성화 되었으므로 이 파일을 볼 수 없습니다.",
    "File not found" : "파일을 찾을 수 없음",
    "Readme" : "Readme",
    "Text" : "텍스트",
    "📝 Collaborative document editing" : "📝 협업 문서 편집",
    "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "** 📝 협업 문서 편집!**\n\n- **📝 글쓰기에 집중:** 방해는 없이, 필요한 서식만 적용.\n- **🙋 함께 작업하기:** 친구 및 동료와 공유하고 협업하세요, Nextcloud를 사용하는지는 상관 없습니다!\n- **💾 공개된 형식:** 파일이 [Markdown](https://en.wikipedia.org/wiki/Markdown)으로 저장되어, 다른 텍스트 앱에서도 편집할 수 있습니다.\n- **✊ 강력한 기반:** 저희는 [🐈 tiptap](https://tiptap.scrumpy.io)을 사용하며 [🦉 ProseMirror](https://prosemirror.net)에 기반합니다. – 많은 감사 드립니다!",
    "Overwrite the file and save the current changes" : "파일을 덮어쓰고 현재의 변경사항을 저장하기",
    "Discard the current changes and load the latest version" : "현재의 변경사항을 취소하고 최신 버전을 불러오기",
    "Reload" : "새로 고침",
    "The document could not be loaded. Please check your internet connection." : "문서를 가져올 수 없습니다. 인터넷 연결을 확인해주십시오.",
    "Reconnect" : "재연결",
    "You've been disconnected from the server." : "서버와의 연결이 끊어졌습니다.",
    "This file is opened read-only as it is currently locked by {user}." : "이 파일은 {user}에 의해 잠겨 있으므로 읽기 전용으로 열립니다.",
    "Enter your name so other people can see who is editing" : "누가 수정하고 있는 지 다른 사람들이 알 수 있도록 이름을 입력하세요.",
    "Enter your name" : "이름을 입력하세요",
    "Guest" : "손님",
    "you" : "나",
    "edit" : "편집",
    "Uploading multiple attachments failed." : "여러 첨부 파일을 업로드에 실패했습니다.",
    "Uploading attachment failed: {error}" : "첨부 파일 업로드 실패: {error}",
    "Uploading attachment failed." : "첨부 파일 업로드에 실패했습니다.",
    "Insert an attachment" : "첨부 파일 삽입",
    "Failed to insert from Files" : "파일로부터 삽입 실패",
    "Preview options" : "미리 보기 옵션",
    "Text only" : "텍스트만",
    "Show link preview" : "링크 미리 보기 표시",
    "Open in new tab" : "새 탭으로 열기",
    "Copy link" : "링크 주소 복사",
    "Remove link" : "링크 제거",
    "Active people" : "활동 중인 사용자",
    "guest" : "손님",
    "Offline" : "오프라인",
    "Offline, changes will be saved when online" : "오프라인입니다. 변경 사항은 온라인이 되었을 때 저장됩니다.",
    "Saving …" : "저장중 …",
    "Saved" : "저장됨",
    "Last saved {lastSave}" : "마지막 저장 {lastSave}",
    "The document has been changed outside of the editor. The changes cannot be applied." : "문서가 에디터 밖에서 변경되었습니다. 변경사항이 적용되지 않습니다.",
    "Unsaved changes" : "저장하지 않은 변경 사항",
    "Save document" : "문서 저장",
    "Last saved" : "마지막 저장",
    "Formatting and shortcuts" : "서식 및 단축키",
    "Speed up your writing with simple shortcuts." : "간단한 단축키들로 글쓰기 속도를 높이세요.",
    "Just type the Markdown syntax or use keyboard shortcuts from below." : "마크다운 구문을 입력하거나 아래의 키보드 단축키를 사용하세요.",
    "Just type the Markdown syntax from below." : "아래의 마크다운 구문을 입력하세요.",
    "Style" : "스타일",
    "Syntax" : "구문",
    "Keyboard shortcuts" : "키보드 단축키",
    "New paragraph" : "새 문단",
    "Enter" : "Enter",
    "Hard line break" : "강제 줄 바꿈",
    "followed by" : "followed by",
    "Backspace" : "백스페이스",
    "Shift" : "쉬프트",
    "Bold" : "굵게",
    "Bold text" : "굵은 텍스트",
    "Italic" : "Italic체",
    "Italicized text" : "기울임꼴 텍스트",
    "Strikethrough" : "취소선",
    "Mistaken text" : "잘못된 텍스트",
    "Underline" : "밑줄",
    "Underlined text" : "밑줄 쳐진 텍스트",
    "Heading 1" : "제목 1",
    "Heading level 1" : "제목 단계 1",
    "Heading 6" : "제목 6",
    "Heading level 6" : "제목 단계 6",
    "Unordered list" : "순서 없는 목록",
    "An item" : "하나의 항목",
    "Ordered list" : "순서 있는 목록",
    "First item" : "첫 항목",
    "Checklist" : "체크리스트",
    "To-Do item" : "해야 할 일",
    "Blockquote" : "블록 인용",
    "Quoted text" : "인용문",
    "Code block" : "코드 블록",
    "Some code" : "코드",
    "Link" : "링크",
    "Insert emoji" : "이모지 삽입",
    "emoji" : "이모지",
    "Mention someone" : "누군가를 언급",
    "name" : "이름",
    "Smart picker" : "스마트 피커",
    "something" : "무언가",
    "Action" : "동작",
    "Undo" : "실행 취소",
    "Redo" : "다시 실행",
    "Toggle outline" : "외곽선 켜고 끄기",
    "Alt" : "Alt",
    "Edit link" : "링크 수정",
    "Save changes" : "설정 저장",
    "Cancel" : "취소",
    "URL" : "URL",
    "Save" : "저장",
    "Upload from computer" : "컴퓨터에서 업로드",
    "Insert from Files" : "파일로부터 삽입",
    "Formatting help" : "서식 도움말",
    "Link to file or folder" : "파일이나 폴더로 링크",
    "Link to website" : "웹사이트로 링크",
    "Update link" : "링크 갱신",
    "Open the Smart Picker" : "스마트 피커 열기",
    "{menuItemName}, \"{selectedSubMenuItemName}\" is selected" : "{menuItemName}, \"{selectedSubMenuItemName}\"(이)가 선택되었습니다.",
    "Insert result" : "결과 삽입",
    "Nextcloud Assistant result copied" : "Nextcloud 어시스턴트 결과 복사됨",
    "Could not copy result to clipboard" : "클립보드에 결과를 복사할 수 없음",
    "Translate" : "번역:",
    "Show assistant results" : "어시스턴트 결과 표시",
    "Assistant results" : "어시스턴트 결과",
    "Nextcloud Assistant" : "Nextcloud 어시스턴트",
    "Show result" : "결과 표시",
    "Delete task" : "결과 삭제",
    "_%n word_::_%n words_" : ["%n개 단어"],
    "_%n char_::_%n chars_" : ["%n개 글자"],
    "Remaining actions" : "남은 동작",
    "Editor actions" : "편집기 동작",
    "Formatting menu bar" : "서식 메뉴 바",
    "Full width editor" : "전체 너비 편집기",
    "Translate from {language}" : "{language}에서 번역",
    "Translate to {language}" : "{language}(으)로 번역",
    "Translation failed" : "번역 실패",
    "To translate individual parts of the text, select it before using the translate function." : "텍스트의 부분들을 각각 번역하려면, 번역 기능을 사용하기 전 먼저 선택을 하세요.",
    "Translate from" : "다음을 번역",
    "Select language" : "언어 선택",
    "Text to translate from" : "번역할 텍스트",
    "to" : "에서",
    "Translate to" : "다음으로 번역",
    "Translated text result" : "번역된 텍스트 결과",
    "Replace" : "바꾸기",
    "Insert" : "삽입",
    "Edit" : "편집",
    "No emoji found" : "이모지 없음",
    "No command found" : "명령 없음",
    "No user found" : "사용자 없음",
    "No suggestion found" : "제안 없음",
    "Upload" : "업로드",
    "Copy code block" : "코드 블록 복사",
    "Copy code" : "코드 복사",
    "Code block options" : "코드 블록 옵션",
    "Code block language" : "코드 블록 언어",
    "e.g. php, javascript, json…" : "예: php, 자바스크립트, json",
    "Source code" : "소스 코드",
    "Diagram" : "다이어그램",
    "Both" : "둘 다",
    "Mermaid documentation" : "Mermaid 문서",
    "Failed to load" : "불러오기 실패",
    "Could not find image in attachments list." : "첨부 파일 목록에서 이미지를 찾지 못했습니다.",
    "Delete this attachment" : "이 첨부 파일 삭제",
    "Delete this image" : "이 이미지 삭제",
    "Add row before" : "앞에 행 추가",
    "Add row after" : "뒤에 행 추가",
    "Delete this row" : "이 행 삭제",
    "Left align column" : "열 왼쪽 정렬",
    "Center align column" : "열 중앙 정렬",
    "Right align column" : "열 오른쪽 정렬",
    "Add column before" : "앞에 열 추가",
    "Add column after" : "뒤에 열 추가",
    "Delete this column" : "이 열 삭제",
    "Delete this table" : "이 표 삭제",
    "Add row below" : "아래에 행 추가",
    "Show folder description" : "폴더 설명 보이기",
    "Hide outline" : "개요 숨기기",
    "Show outline" : "개요 보이기",
    "Done" : "완료",
    "Headings" : "제목",
    "Heading 2" : "제목 2",
    "Heading 3" : "제목 3",
    "Heading 4" : "제목 4",
    "Heading 5" : "제목 5",
    "Lists" : "목록",
    "To-Do list" : "해야 할 일 목록",
    "Increase indentation" : "들여쓰기 증가",
    "Decrease indentation" : "들여쓰기 감소",
    "Blocks" : "블록",
    "Info callout" : "정보 설명선",
    "Success callout" : "성공 설명선",
    "Warning callout" : "경고 설명선",
    "Danger callout" : "위험 설명선",
    "Table" : "표",
    "Details" : "세부사항",
    "Insert link" : "링크 삽입",
    "Insert attachment" : "첨부 파일 삽입",
    "Command" : "명령",
    "Ctrl" : "Ctrl",
    "Option" : "옵션",
    "Formatting" : "서식",
    "Select file or folder to link to" : "링크할 파일이나 폴더 선택",
    "Choose" : "선택",
    "Choose {file}" : "{file} 선택",
    "Add folder description" : "폴더 설명 추가",
    "\"{name}\" already exist!" : "\"{name}\" (이)가 이미 존재합니다!",
    "Created \"{name}\"" : "\"{name}\" 생성함",
    "Copied to the clipboard" : "클립보드에 복사됨",
    "Could not copy to the clipboard" : "클립보드에 복사할 수 없음",
    "Front matter" : "머리말",
    "Link to this section" : "이 부분으로 링크",
    "Close outline view" : "개요 닫기",
    "Outline" : "개요",
    "Edit guest name" : "손님 이름 편집하기",
    "Save guest name" : "손님 이름 저장하기",
    "Cannot copy, please copy the link manually" : "복사할 수 없습니다, 링크를 수동으로 복사하세요.",
    "Copy link to clipboard" : "링크를 클립보드에 복사"
},
"nplurals=1; plural=0;");
